Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( DialogBoxStyle = lipgloss.NewStyle(). Border(lipgloss.RoundedBorder()). BorderForeground(lipgloss.Color("#874BFD")). Padding(1, 0). BorderTop(true). BorderLeft(true). BorderRight(true). BorderBottom(true) HelpStyle = lipgloss.NewStyle().Foreground(lipgloss.Color("240")) SuccessStyle = lipgloss.NewStyle().Foreground(lipgloss.Color("42")).Bold(true) InfoStyle = lipgloss.NewStyle().Foreground(lipgloss.Color("205")).Bold(true) )
var DocStyle = lipgloss.NewStyle().Margin(1, 2)
Functions ¶
Types ¶
type ChooseServiceMsg ¶
type ChooseServiceMsg struct {
Service string
}
A message to indicate that the user has chosen a service.
type ClearStatusMsg ¶
type ClearStatusMsg struct{}
ClearStatusMsg is sent to clear the status message from the view.
type Composer ¶
type Composer struct {
// contains filtered or unexported fields
}
Composer model holds the state of the email composition UI.
func NewComposer ¶
NewComposer initializes a new composer model.
type Credentials ¶
A message to indicate that the user has entered their credentials.
type EmailResultMsg ¶
type EmailResultMsg struct {
Err error
}
EmailResultMsg is sent after an email sending attempt. If Err is not nil, the email failed to send.
type EmailsFetchedMsg ¶
A message containing the fetched emails.
type FetchErr ¶
type FetchErr error
A message to indicate that an error occurred while fetching emails.
type Login ¶
type Login struct {
// contains filtered or unexported fields
}
Login holds the state for the login form.
type SendEmailMsg ¶
A message to indicate that an email has been sent.
Click to show internal directories.
Click to hide internal directories.